var servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1PageNumber =
[
    [ "com::sun::star::text::TextField", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1PageNumber.html#ac5c12dd117b70431d72eeb6ab9507fd2", null ],
    [ "NumberingType", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1PageNumber.html#ae3dc42096fd541eb9a8b3c3e0654582b", null ],
    [ "Offset", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1PageNumber.html#acd0d8c054f0c0f80c2d1890c7e4cec06", null ],
    [ "SubType", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1PageNumber.html#a166139f59ed99490e8bd8997d45d49f6", null ],
    [ "UserText", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1PageNumber.html#a54ebb6561fbd1c90718e1a40a29dd8ee", null ]
];